==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/corevideo/CVImageBufferTransferFunction.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.corevideo;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.corefoundation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.opengles.*;
import org.robovm.apple.metal.*;
/*</imports>*/

/*<javadoc>*/
/*</javadoc>*/
/*<annotations>*/@Library("CoreVideo") @StronglyLinked/*</annotations>*/
@Marshaler(/*<name>*/CVImageBufferTransferFunction/*</name>*/.Marshaler.class)
/*<visibility>*/public/*</visibility>*/ class /*<name>*/CVImageBufferTransferFunction/*</name>*/ 
    extends /*<extends>*/GlobalValueEnumeration<CFString>/*</extends>*/
    /*<implements>*//*</implements>*/ {

    static { Bro.bind(/*<name>*/CVImageBufferTransferFunction/*</name>*/.class); }

    /*<marshalers>*/
    public static class Marshaler {
        @MarshalsPointer
        public static CVImageBufferTransferFunction toObject(Class<CVImageBufferTransferFunction> cls, long handle, long flags) {
            CFString o = (CFString) CFType.Marshaler.toObject(CFString.class, handle, flags);
            if (o == null) {
                return null;
            }
            return CVImageBufferTransferFunction.valueOf(o);
        }
        @MarshalsPointer
        public static long toNative(CVImageBufferTransferFunction o, long flags) {
            if (o == null) {
                return 0L;
            }
            return CFType.Marshaler.toNative(o.value(), flags);
        }
    }
    public static class AsListMarshaler {
        @MarshalsPointer
        public static List<CVImageBufferTransferFunction> toObject(Class<? extends CFType> cls, long handle, long flags) {
            CFArray o = (CFArray) CFType.Marshaler.toObject(CFArray.class, handle, flags);
            if (o == null) {
                return null;
            }
            List<CVImageBufferTransferFunction> list = new ArrayList<>();
            for (int i = 0; i < o.size(); i++) {
                list.add(CVImageBufferTransferFunction.valueOf(o.get(i, CFString.class)));
            }
            return list;
        }
        @MarshalsPointer
        public static long toNative(List<CVImageBufferTransferFunction> l, long flags) {
            if (l == null) {
                return 0L;
            }
            CFArray array = CFMutableArray.create();
            for (CVImageBufferTransferFunction o : l) {
                array.add(o.value());
            }
            return CFType.Marshaler.toNative(array, flags);
        }
    }
    /*</marshalers>*/

    /*<constants>*/
    /**
     * @since Available in iOS 4.0 and later.
     */
    public static final CVImageBufferTransferFunction ITU_R_709_2 = new CVImageBufferTransferFunction("ITU_R_709_2");
    /**
     * @since Available in iOS 4.0 and later.
     */
    public static final CVImageBufferTransferFunction SMPTE_240M_1995 = new CVImageBufferTransferFunction("SMPTE_240M_1995");
    /**
     * @since Available in iOS 4.0 and later.
     */
    public static final CVImageBufferTransferFunction UseGamma = new CVImageBufferTransferFunction("UseGamma");
    /*</constants>*/
    
    private static /*<name>*/CVImageBufferTransferFunction/*</name>*/[] values = new /*<name>*/CVImageBufferTransferFunction/*</name>*/[] {/*<value_list>*/ITU_R_709_2, SMPTE_240M_1995, UseGamma/*</value_list>*/};
    
    /*<name>*/CVImageBufferTransferFunction/*</name>*/ (String getterName) {
        super(Values.class, getterName);
    }
    
    public static /*<name>*/CVImageBufferTransferFunction/*</name>*/ valueOf(/*<type>*/CFString/*</type>*/ value) {
        for (/*<name>*/CVImageBufferTransferFunction/*</name>*/ v : values) {
            if (v.value().equals(value)) {
                return v;
            }
        }
        throw new IllegalArgumentException("No constant with value " + value + " found in " 
            + /*<name>*/CVImageBufferTransferFunction/*</name>*/.class.getName());
    }
    
    /*<methods>*//*</methods>*/
    
    /*<annotations>*/@Library("CoreVideo") @StronglyLinked/*</annotations>*/
    public static class Values {
    	static { Bro.bind(Values.class); }

        /*<values>*/
        /**
         * @since Available in iOS 4.0 and later.
         */
        @GlobalValue(symbol="kCVImageBufferTransferFunction_ITU_R_709_2", optional=true)
        public static native CFString ITU_R_709_2();
        /**
         * @since Available in iOS 4.0 and later.
         */
        @GlobalValue(symbol="kCVImageBufferTransferFunction_SMPTE_240M_1995", optional=true)
        public static native CFString SMPTE_240M_1995();
        /**
         * @since Available in iOS 4.0 and later.
         */
        @GlobalValue(symbol="kCVImageBufferTransferFunction_UseGamma", optional=true)
        public static native CFString UseGamma();
        /*</values>*/
    }
}

==> robovm-cocoatouch-2.3.18-sources.jar: org/robovm/apple/corevideo/CVImageBufferTransferFunction.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.corevideo;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.corefoundation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.opengles.*;
import org.robovm.apple.metal.*;
import org.robovm.apple.iosurface.*;
/*</imports>*/

/*<javadoc>*/
/*</javadoc>*/
/*<annotations>*/@Library("CoreVideo") @StronglyLinked/*</annotations>*/
@Marshaler(/*<name>*/CVImageBufferTransferFunction/*</name>*/.Marshaler.class)
/*<visibility>*/public/*</visibility>*/ class /*<name>*/CVImageBufferTransferFunction/*</name>*/ 
    extends /*<extends>*/GlobalValueEnumeration<CFString>/*</extends>*/
    /*<implements>*//*</implements>*/ {

    static { Bro.bind(/*<name>*/CVImageBufferTransferFunction/*</name>*/.class); }

    /*<marshalers>*/
    public static class Marshaler {
        @MarshalsPointer
        public static CVImageBufferTransferFunction toObject(Class<CVImageBufferTransferFunction> cls, long handle, long flags) {
            CFString o = (CFString) CFType.Marshaler.toObject(CFString.class, handle, flags);
            if (o == null) {
                return null;
            }
            return CVImageBufferTransferFunction.valueOf(o);
        }
        @MarshalsPointer
        public static long toNative(CVImageBufferTransferFunction o, long flags) {
            if (o == null) {
                return 0L;
            }
            return CFType.Marshaler.toNative(o.value(), flags);
        }
    }
    public static class AsListMarshaler {
        @MarshalsPointer
        public static List<CVImageBufferTransferFunction> toObject(Class<? extends CFType> cls, long handle, long flags) {
            CFArray o = (CFArray) CFType.Marshaler.toObject(CFArray.class, handle, flags);
            if (o == null) {
                return null;
            }
            List<CVImageBufferTransferFunction> list = new ArrayList<>();
            for (int i = 0; i < o.size(); i++) {
                list.add(CVImageBufferTransferFunction.valueOf(o.get(i, CFString.class)));
            }
            return list;
        }
        @MarshalsPointer
        public static long toNative(List<CVImageBufferTransferFunction> l, long flags) {
            if (l == null) {
                return 0L;
            }
            CFArray array = CFMutableArray.create();
            for (CVImageBufferTransferFunction o : l) {
                array.add(o.value());
            }
            return CFType.Marshaler.toNative(array, flags);
        }
    }
    /*</marshalers>*/

    /*<constants>*/
    public static final CVImageBufferTransferFunction ITU_R_709_2 = new CVImageBufferTransferFunction("ITU_R_709_2");
    public static final CVImageBufferTransferFunction SMPTE_240M_1995 = new CVImageBufferTransferFunction("SMPTE_240M_1995");
    public static final CVImageBufferTransferFunction UseGamma = new CVImageBufferTransferFunction("UseGamma");
    /**
     * @since Available in iOS 11.0 and later.
     */
    public static final CVImageBufferTransferFunction sRGB = new CVImageBufferTransferFunction("sRGB");
    /**
     * @since Available in iOS 9.0 and later.
     */
    public static final CVImageBufferTransferFunction ITU_R_2020 = new CVImageBufferTransferFunction("ITU_R_2020");
    /**
     * @since Available in iOS 10.0 and later.
     */
    public static final CVImageBufferTransferFunction SMPTE_ST_428_1 = new CVImageBufferTransferFunction("SMPTE_ST_428_1");
    /**
     * @since Available in iOS 11.0 and later.
     */
    public static final CVImageBufferTransferFunction SMPTE_ST_2084_PQ = new CVImageBufferTransferFunction("SMPTE_ST_2084_PQ");
    /**
     * @since Available in iOS 11.0 and later.
     */
    public static final CVImageBufferTransferFunction ITU_R_2100_HLG = new CVImageBufferTransferFunction("ITU_R_2100_HLG");
    /**
     * @since Available in iOS 12.0 and later.
     */
    public static final CVImageBufferTransferFunction Linear = new CVImageBufferTransferFunction("Linear");
    /*</constants>*/
    
    private static /*<name>*/CVImageBufferTransferFunction/*</name>*/[] values = new /*<name>*/CVImageBufferTransferFunction/*</name>*/[] {/*<value_list>*/ITU_R_709_2, SMPTE_240M_1995, UseGamma, sRGB, ITU_R_2020, SMPTE_ST_428_1, SMPTE_ST_2084_PQ, ITU_R_2100_HLG, Linear/*</value_list>*/};
    
    /*<name>*/CVImageBufferTransferFunction/*</name>*/ (String getterName) {
        super(Values.class, getterName);
    }
    
    public static /*<name>*/CVImageBufferTransferFunction/*</name>*/ valueOf(/*<type>*/CFString/*</type>*/ value) {
        for (/*<name>*/CVImageBufferTransferFunction/*</name>*/ v : values) {
            if (v.value().equals(value)) {
                return v;
            }
        }
        throw new IllegalArgumentException("No constant with value " + value + " found in " 
            + /*<name>*/CVImageBufferTransferFunction/*</name>*/.class.getName());
    }
    
    /*<methods>*//*</methods>*/
    
    /*<annotations>*/@Library("CoreVideo") @StronglyLinked/*</annotations>*/
    public static class Values {
    	static { Bro.bind(Values.class); }

        /*<values>*/
        @GlobalValue(symbol="kCVImageBufferTransferFunction_ITU_R_709_2", optional=true)
        public static native CFString ITU_R_709_2();
        @GlobalValue(symbol="kCVImageBufferTransferFunction_SMPTE_240M_1995", optional=true)
        public static native CFString SMPTE_240M_1995();
        @GlobalValue(symbol="kCVImageBufferTransferFunction_UseGamma", optional=true)
        public static native CFString UseGamma();
        /**
         * @since Available in iOS 11.0 and later.
         */
        @GlobalValue(symbol="kCVImageBufferTransferFunction_sRGB", optional=true)
        public static native CFString sRGB();
        /**
         * @since Available in iOS 9.0 and later.
         */
        @GlobalValue(symbol="kCVImageBufferTransferFunction_ITU_R_2020", optional=true)
        public static native CFString ITU_R_2020();
        /**
         * @since Available in iOS 10.0 and later.
         */
        @GlobalValue(symbol="kCVImageBufferTransferFunction_SMPTE_ST_428_1", optional=true)
        public static native CFString SMPTE_ST_428_1();
        /**
         * @since Available in iOS 11.0 and later.
         */
        @GlobalValue(symbol="kCVImageBufferTransferFunction_SMPTE_ST_2084_PQ", optional=true)
        public static native CFString SMPTE_ST_2084_PQ();
        /**
         * @since Available in iOS 11.0 and later.
         */
        @GlobalValue(symbol="kCVImageBufferTransferFunction_ITU_R_2100_HLG", optional=true)
        public static native CFString ITU_R_2100_HLG();
        /**
         * @since Available in iOS 12.0 and later.
         */
        @GlobalValue(symbol="kCVImageBufferTransferFunction_Linear", optional=true)
        public static native CFString Linear();
        /*</values>*/
    }
}
